# New in 0.17.4 (2021-09-20)

## Changes

-   Support for PyTorch Lightning 1.7 [#1622].
-   Allow `flax` to use any mutable states used by a model generically with {class}`~scvi.module.base.TrainStateWithState` [#1665], [#1700].
-   Update publication links in `README` [#1667].
-   Docs now include floating window cross references with `hoverxref`, external links with `linkcode`, and `grid` [#1678].

## Bug Fixes

-   Fix `get_likelihood_parameters()` failure when `gene_likelihood != "zinb"` in {class}`~scvi.model.base.RNASeqMixin` [#1618].
-   Fix exception logic when not using the observed library size in {class}`~scvi.module.VAE` initialization [#1660].
-   Replace instances of `super().__init__()` with an argument in `super()`, causing `autoreload` extension to throw errors [#1671].
-   Change cell2location tutorial causing docs build to fail [#1674].
-   Replace instances of `max_epochs` as `int`s for new PyTorch Lightning [#1686].
-   Catch case when `torch.backends.mps` is not implemented [#1692].
-   Fix Poisson sampling in {meth}`~scvi.module.VAE.sample` [#1702].

## Contributors

-   [@adamgayoso]
-   [@watiss]
-   [@mkarikom]
-   [@tommycelsius]
-   [@ricomnl]

[#1618]: https://github.com/scverse/scvi-tools/pull/1618
[#1622]: https://github.com/scverse/scvi-tools/pull/1622
[#1660]: https://github.com/scverse/scvi-tools/pull/1660
[#1665]: https://github.com/scverse/scvi-tools/pull/1665
[#1667]: https://github.com/scverse/scvi-tools/pull/1667
[#1671]: https://github.com/scverse/scvi-tools/pull/1671
[#1674]: https://github.com/scverse/scvi-tools/pull/1674
[#1678]: https://github.com/scverse/scvi-tools/pull/1678
[#1686]: https://github.com/scverse/scvi-tools/pull/1686
[#1692]: https://github.com/scverse/scvi-tools/pull/1692
[#1700]: https://github.com/scverse/scvi-tools/pull/1700
[#1702]: https://github.com/scverse/scvi-tools/pull/1702
[@adamgayoso]: https://github.com/adamgayoso
[@watiss]: https://github.com/watiss
[@tommycelsius]: https://github.com/tommycelsius
[@mkarikom]: https://github.com/mkarikom
[@ricomnl]: https://github.com/ricomnl
